==> haskell-floatinghex-0.4-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-floatinghex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 FloatingHex
version:              0.4
visibility:           public
id:                   FloatingHex-0.4-B2JmOQsAjjd4PESjEpQjAq
key:                  FloatingHex-0.4-B2JmOQsAjjd4PESjEpQjAq
license:              BSD-3-Clause
copyright:            Levent Erkok
maintainer:           erkokl@gmail.com
author:               Levent Erkok
synopsis:             Read and write hexadecimal floating point numbers
description:
    Read and write hexadecimal floating point numbers. Provides a quasiquoter for
    entering hex-float literals, and a function for printing them in hexadecimal.

    See: <http://www.open-std.org/jtc1/sc22/wg14/www/docs/n1256.pdf>, pages 57-58.
    We slightly diverge from the standard and do not allow for the "floating-suffix,"
    as the type inference of Haskell makes this unnecessary.

    For details, please see: <http://github.com/LeventErkok/FloatingHex/>

category:             Tools
abi:                  94a57bbd2653c6df1ae5b635f15820ea
exposed:              True
exposed-modules:      Data.Numbers.FloatingHex
import-dirs:          /usr/lib/ghc-8.10.1/site-local/FloatingHex-0.4
library-dirs:         /usr/lib/ghc-8.10.1/site-local/FloatingHex-0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/FloatingHex-0.4
hs-libraries:         HSFloatingHex-0.4-B2JmOQsAjjd4PESjEpQjAq
depends:              base-4.14.0.0 template-haskell-2.16.0.0
haddock-interfaces:   /usr/share/doc/haskell-floatinghex/html/FloatingHex.haddock
haddock-html:         /usr/share/doc/haskell-floatinghex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-floatinghex-0.4-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-floatinghex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 FloatingHex
version:              0.4
visibility:           public
id:                   FloatingHex-0.4-3B9ITepmHBOGuAKQsODcGE
key:                  FloatingHex-0.4-3B9ITepmHBOGuAKQsODcGE
license:              BSD-3-Clause
copyright:            Levent Erkok
maintainer:           erkokl@gmail.com
author:               Levent Erkok
synopsis:             Read and write hexadecimal floating point numbers
description:
    Read and write hexadecimal floating point numbers. Provides a quasiquoter for
    entering hex-float literals, and a function for printing them in hexadecimal.

    See: <http://www.open-std.org/jtc1/sc22/wg14/www/docs/n1256.pdf>, pages 57-58.
    We slightly diverge from the standard and do not allow for the "floating-suffix,"
    as the type inference of Haskell makes this unnecessary.

    For details, please see: <http://github.com/LeventErkok/FloatingHex/>

category:             Tools
abi:                  54ad9ea3f00917714cb2111d2aab9eda
exposed:              True
exposed-modules:      Data.Numbers.FloatingHex
import-dirs:          /usr/lib/ghc-8.10.2/site-local/FloatingHex-0.4
library-dirs:         /usr/lib/ghc-8.10.2/site-local/FloatingHex-0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/FloatingHex-0.4
hs-libraries:         HSFloatingHex-0.4-3B9ITepmHBOGuAKQsODcGE
depends:              base-4.14.1.0 template-haskell-2.16.0.0
haddock-interfaces:   /usr/share/doc/haskell-floatinghex/html/FloatingHex.haddock
haddock-html:         /usr/share/doc/haskell-floatinghex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
